<h2 id="demo-of-glasseye">Demo of Glasseye</h2>
<h3 id="section-with-some-margin-notes-in-the-tufte-style">Section with some margin notes in the Tufte style</h3>
<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.<side-note>1. tincidunt accumsan odio id gravida. In massa sem, scelerisque et fringilla dapibus, viverra at sem. Aliquam luctus urna a metus condimentum rhoncus iaculis vel est.</side-note> Quisque fringilla efficitur nisi a ullamcorper. Nulla at diam porttitor leo imperdiet imperdiet. Suspendisse potenti. Donec convallis quam eu porttitor tempor. Etiam quis viverra erat, at ultrices mi. Sed suscipit viverra tempor. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Sed molestie varius posuere</p>
<ol style="list-style-type: decimal">
<li>Lorem ipsum dolor sit amet, consectetur adipiscing elit <side-note>2. Quisque fringilla efficitur nisi a ullamcorper.</side-note></li>
<li>Sed suscipit viverra tempor.</li>
<li>Consectetur adipiscing elit. Quisque fringilla.</li>
</ol>
<h3 id="section-with-some-maths">Section with some maths</h3>
<p><margin-note> Pellentesque pellentesque ullamcorper purus et luctus. In nec consequat justo, sed gravida metus. <span class="math display">\[ 0.26 = (1-d)^{28} \]</span> <span class="math display">\[ ln(0.26) = 28 ln(1-d) \]</span> <span class="math display">\[ \frac{ln(0.26)}{28} = ln(1-d) \]</span> <span class="math display">\[ e^{\frac{ln(0.26)}{28}} = 1-d \]</span> <span class="math display">\[ 1-e^{\frac{ln(0.26)}{28}} = d \]</span> </margin-note></p>
<p>Pellentesque pellentesque ullamcorper purus et luctus. In nec consequat justo, sed gravida metus. In massa sem, scelerisque et fringilla dapibus, viverra at sem. Aliquam luctus urna a metus condimentum rhoncus iaculis vel est. Vestibulum tincidunt accumsan odio id gravida. Mauris tristique interdum auctor. Morbi vitae porta tellus. Donec risus urna, fringilla vitae sagittis eu, scelerisque sed justo. Cras interdum diam nulla, eget pellentesque urna tempor sit amet.</p>
<h3 id="section-with-a-donut-chart">Section with a donut chart</h3>
<p>Aliquam luctus urna a metus condimentum rhoncus iaculis vel est. Vestibulum tincidunt accumsan odio id gravida. Mauris tristique interdum auctor. Morbi vitae porta tellus. Donec risus urna, fringilla vitae sagittis eu, scelerisque sed justo. Cras interdum diam nulla, eget pellentesque urna tempor sit amet.</p>
<p><margin-note> <donut> {&quot;labels&quot;: [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;], &quot;values&quot;: [2,2,7]} </donut> Aliquam luctus urna a metus condimentum rhoncus iaculis vel est. Vestibulum tincidunt accumsan odio id gravida. </margin-note></p>
<h3 id="section-with-a-line-chart">Section with a line chart</h3>
<p>Quisque laoreet semper ex in aliquet. Pellentesque pharetra sed augue id porta. Vestibulum urna est, ultricies eu porta in, dapibus sit amet libero. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent mollis sapien sit amet placerat maximus. Mauris semper a metus non accumsan. Nunc porta nulla eu augue varius, eu efficitur neque dapibus. Donec vitae ullamcorper nulla, quis sollicitudin erat. Sed sed purus et ipsum scelerisque viverra non ut ex. Donec metus ipsum, commodo eget est ac, tempus varius dui. Pellentesque convallis sapien non fermentum viverra. Duis aliquet vel mauris et tincidunt. Quisque eleifend lobortis purus, in gravida eros. Cras vulputate imperdiet risus, sed pretium magna volutpat ut. Vivamus auctor mi mattis eros malesuada posuere aliquam in arcu. Morbi diam turpis, aliquet id blandit vitae, convallis at ex.</p>
<p>Suspendisse condimentum lacus cursus mi consectetur euismod. Nulla aliquam nisi sed velit rhoncus bibendum. Aliquam vulputate justo ligula, ac rutrum turpis venenatis in. Quisque a nibh lacinia, pharetra velit eu, volutpat est. Nunc mauris nunc, viverra at erat ut, vulputate facilisis elit. Praesent dapibus non leo rhoncus molestie. In vulputate arcu viverra, ornare ante rhoncus, tincidunt metus. Phasellus gravida nunc mauris, non porta dui aliquam vel. Vivamus a diam vel nisl dignissim blandit. Praesent a quam faucibus, convallis lacus vel, fringilla lectus. Pellentesque et dignissim leo. Duis nisi magna, varius nec vestibulum et, scelerisque eget neque. Nullam quis risus nisi. Aliquam id ex semper, facilisis nibh sed, tincidunt massa.</p>
<p><margin-note> <line_chart>{&quot;x&quot;: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14], &quot;y&quot;: [22, 43, 12, 8, 2, 3, 4, 6, 5, 4, 3, 2, 1, 2], &quot;labels&quot;: [&quot;width&quot;, &quot;height&quot;]}</line_chart> Praesent mollis sapien sit amet placerat maximus. Mauris semper a metus non accumsan. Nunc porta nulla eu augue varius, eu efficitur neque dapibus. </margin-note></p>
<p>Suspendisse condimentum lacus cursus mi consectetur euismod. Nulla aliquam nisi sed velit rhoncus bibendum. Aliquam vulputate justo ligula, ac rutrum turpis venenatis in. Quisque a nibh lacinia, pharetra velit eu, volutpat est. Nunc mauris nunc, viverra at erat ut, vulputate facilisis elit. Praesent dapibus non leo rhoncus molestie. In vulputate arcu viverra, ornare ante rhoncus, tincidunt metus. Phasellus gravida nunc mauris, non porta dui aliquam vel. Vivamus a diam vel nisl dignissim blandit. Praesent a quam faucibus, convallis lacus vel, fringilla lectus. Pellentesque et dignissim leo. Duis nisi magna, varius nec vestibulum et, scelerisque eget neque. Nullam quis risus nisi. Aliquam id ex semper, facilisis nibh sed, tincidunt massa.</p>
<p>Quisque laoreet semper ex in aliquet. Pellentesque pharetra sed augue id porta. Vestibulum urna est, ultricies eu porta in, dapibus sit amet libero. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent mollis sapien sit amet placerat maximus. Mauris semper a metus non accumsan. Nunc porta nulla eu augue varius, eu efficitur neque dapibus. Donec vitae ullamcorper nulla, quis sollicitudin erat. Sed sed purus et ipsum scelerisque viverra non ut ex. Donec metus ipsum, commodo eget est ac, tempus varius dui. Pellentesque convallis sapien non fermentum viverra. Duis aliquet vel mauris et tincidunt. Quisque eleifend lobortis purus, in gravida eros. Cras vulputate imperdiet risus, sed pretium magna volutpat ut. Vivamus auctor mi mattis eros malesuada posuere aliquam in arcu. Morbi diam turpis, aliquet id blandit vitae, convallis at ex.</p>
<p>Suspendisse condimentum lacus cursus mi consectetur euismod. Nulla aliquam nisi sed velit rhoncus bibendum. Aliquam vulputate justo ligula, ac rutrum turpis venenatis in. Quisque a nibh lacinia, pharetra velit eu, volutpat est. Nunc mauris nunc, viverra at erat ut, vulputate facilisis elit. Praesent dapibus non leo rhoncus molestie. In vulputate arcu viverra, ornare ante rhoncus, tincidunt metus. Phasellus gravida nunc mauris, non porta dui aliquam vel. Vivamus a diam vel nisl dignissim blandit. Praesent a quam faucibus, convallis lacus vel, fringilla lectus. Pellentesque et dignissim leo. Duis nisi magna, varius nec vestibulum et, scelerisque eget neque. Nullam quis risus nisi. Aliquam id ex semper, facilisis nibh sed, tincidunt massa.</p>
<p><margin-note> <treemap>{ &quot;name&quot;: &quot;All&quot;, &quot;children&quot;: [{ &quot;name&quot;: &quot;Bakery&quot;, &quot;size&quot;: 34 }, { &quot;name&quot;: &quot;Tinned Goods&quot;, &quot;size&quot;: 56 }, { &quot;name&quot;: &quot;Meat and Fish&quot;, &quot;children&quot;: [{ &quot;name&quot;: &quot;Meat&quot;, &quot;children&quot;: [{ &quot;name&quot;: &quot;Poultry&quot;, &quot;size&quot;: 15 }, { &quot;name&quot;: &quot;Beef&quot;, &quot;size&quot;: 17 }]}, { &quot;name&quot;: &quot;Fish&quot;, &quot;size&quot;: 89 } ] }] }</treemap></p>
<p>Suspendisse condimentum lacus cursus mi consectetur euismod. Nulla aliquam nisi sed velit rhoncus bibendum. </margin-note></p>
<p>Quisque laoreet semper ex in aliquet. Pellentesque pharetra sed augue id porta. Vestibulum urna est, ultricies eu porta in, dapibus sit amet libero. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent mollis sapien sit amet placerat maximus. Mauris semper a metus non accumsan. Nunc porta nulla eu augue varius, eu efficitur neque dapibus. Donec vitae ullamcorper nulla, quis sollicitudin erat. Sed sed purus et ipsum scelerisque viverra non ut ex. Donec metus ipsum, commodo eget est ac, tempus varius dui. Pellentesque convallis sapien non fermentum viverra. Duis aliquet vel mauris et tincidunt. Quisque eleifend lobortis purus, in gravida eros. Cras vulputate imperdiet risus, sed pretium magna volutpat ut. Vivamus auctor mi mattis eros malesuada posuere aliquam in arcu. Morbi diam turpis, aliquet id blandit vitae, convallis at ex.</p>
<p>Suspendisse condimentum lacus cursus mi consectetur euismod. Nulla aliquam nisi sed velit rhoncus bibendum. Aliquam vulputate justo ligula, ac rutrum turpis venenatis in. Quisque a nibh lacinia, pharetra velit eu, volutpat est. Nunc mauris nunc, viverra at erat ut, vulputate facilisis elit. Praesent dapibus non leo rhoncus molestie. In vulputate arcu viverra, ornare ante rhoncus, tincidunt metus. Phasellus gravida nunc mauris, non porta dui aliquam vel. Vivamus a diam vel nisl dignissim blandit. Praesent a quam faucibus, convallis lacus vel, fringilla lectus. Pellentesque et dignissim leo. Duis nisi magna, varius nec vestibulum et, scelerisque eget neque. Nullam quis risus nisi. Aliquam id ex semper, facilisis nibh sed, tincidunt massa.</p>
<p><sim_plot>&quot;forD3.csv&quot;</sim_plot></p>
<p>Quisque laoreet semper ex in aliquet. Pellentesque pharetra sed augue id porta. Vestibulum urna est, ultricies eu porta in, dapibus sit amet libero. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent mollis sapien sit amet placerat maximus. Mauris semper a metus non accumsan. Nunc porta nulla eu augue varius, eu efficitur neque dapibus. Donec vitae ullamcorper nulla, quis sollicitudin erat. Sed sed purus et ipsum scelerisque viverra non ut ex. Donec metus ipsum, commodo eget est ac, tempus varius dui. Pellentesque convallis sapien non fermentum viverra. Duis aliquet vel mauris et tincidunt. Quisque eleifend lobortis purus, in gravida eros. Cras vulputate imperdiet risus, sed pretium magna volutpat ut. Vivamus auctor mi mattis eros malesuada posuere aliquam in arcu. Morbi diam turpis, aliquet id blandit vitae, convallis at ex.</p>
<p>Suspendisse condimentum lacus cursus mi consectetur euismod. Nulla aliquam nisi sed velit rhoncus bibendum. Aliquam vulputate justo ligula, ac rutrum turpis venenatis in. Quisque a nibh lacinia, pharetra velit eu, volutpat est. Nunc mauris nunc, viverra at erat ut, vulputate facilisis elit. Praesent dapibus non leo rhoncus molestie. In vulputate arcu viverra, ornare ante rhoncus, tincidunt metus. Phasellus gravida nunc mauris, non porta dui aliquam vel. Vivamus a diam vel nisl dignissim blandit. Praesent a quam faucibus, convallis lacus vel, fringilla lectus. Pellentesque et dignissim leo. Duis nisi magna, varius nec vestibulum et, scelerisque eget neque. Nullam quis risus nisi. Aliquam id ex semper, facilisis nibh sed, tincidunt massa.</p>
<p><dot_plot>&quot;dotplot.csv&quot;</dot_plot></p>
