<!DOCTYPE html>
<head>
  <meta charset="utf-8"/>
  <title>Glasseye</title>
  <link href='http://fonts.googleapis.com/css?family=Raleway' rel='stylesheet' type='text/css'>
  <link href='http://fonts.googleapis.com/css?family=Droid%20Sans' rel='stylesheet' type='text/css'>
  <link href='http://fonts.googleapis.com/css?family=Lato' rel='stylesheet' type='text/css'>
  <link rel="stylesheet" href="css/tufte.css"/>
  <link rel="stylesheet" href="css/glasseyeCharts.css"/>
  <link rel="stylesheet" href="font-awesome/css/font-awesome.min.css">
  <script src="js/d3.min.js"></script>
  <script src="http://labratrevenge.com/d3-tip/javascripts/d3.tip.v0.6.3.js"></script>
  <script src="js/glasseyeCharts.js"></script>
</head>
<body>
  
    <div id = "tufte_container">
    </div>

<!--glasseye-->
<script type="text/javascript">
(function () {
  var script = document.createElement("script");
  script.type = "text/javascript";
  script.src  = "https://cdn.mathjax.org/mathjax/latest/MathJax.js?config=TeX-AMS-MML_HTMLorMML";
  document.getElementsByTagName("head")[0].appendChild(script);
})();
</script>

</body>
</html>
