html { font-size: 10px; }


body { width: 87.5%;
       margin-left: auto;
       margin-right: auto;
       padding-left: 12.5%;
       font-family: 'Raleway';
       padding-bottom: 20rem;
       color: #777;
       max-width: 1200px; }

h1 {  font-family: 'Lato';
      font-weight: 400;
      margin-top: 4rem;
      margin-bottom: 2rem;
      font-size: 2.5rem;
      line-height: 1;
      width: 55%; }

h2 {  font-family: 'Lato';
      font-weight: 400;
      margin-top: 2.1rem;
      margin-bottom: 0;
      font-size: 2rem;
      line-height: 1; }

h3 {  font-family: 'Lato';
      font-style: italic;
      font-weight: 400;
      font-size: 1.7rem;
      margin-top: 2rem;
      margin-bottom: 0;
      line-height: 1; }

h4, h5, h6 {  font-family: 'Lato';
      font-weight: 400;
      font-size: 1.5rem;
      margin-top: 2rem;
      margin-bottom: 0;
      line-height: 1; }

subtitle { 
           font-family: 'Lato';
           font-style: italic;
           margin-top: 1rem;
           margin-bottom: 1rem;
           font-size: 1.8rem;
           display: block;
           line-height: 1; }

table { width: 53%;
        text-align: right;
        font-size: 1.4rem;
        line-height: 1.4;
        margin-top: 1.4rem;
        margin-bottom: 1.4rem;
        margin-left: 1%;
        margin-right: 1%;
        border-top: 2px solid #333333;
        border-bottom: 2px solid #333333;
        border-collapse: separate; 
        border-spacing: 0 5px;
        -webkit-font-feature-settings: 'tnum'; /* This is technically redundant */
        -moz-font-feature-settings: 'tnum';
        -ms-font-feature-settings: 'tnum'; }

thead th { border-bottom: 1px solid #333333;
           font-weight: 400; 
           border-collapse: separate; 
           border-spacing: 5px 5px;}

article { position: relative;
          padding-top: 5rem; }

p, .list-container { font-size: 1.4rem;
    line-height: 2rem;
    margin-top: 1.4rem;
    margin-bottom: 1.4rem;
    width: 55%;
    padding-right: 0;
    vertical-align: baseline; }


@media screen and (max-width: 600px) { p { width: 65%; }}
@media screen and (max-width: 400px) { p { width: 90%; }}

a {  font-size: 1.4rem;
      color: #777;  }


img { max-width: 100%; 
      clear: both;
      margin-bottom: 20px;
      margin-top: 20px;}

sup, sub { vertical-align: baseline;
           position: relative;
           top: -0.4rem; }

sub { top: 0.4rem; }

sup.sidenote-number { 
      font-size: 0.9rem;
       }

.sans { font-family: "Gill Sans", "Gill Sans MT", Calibri, sans-serif; }

code { font-family: Consolas, "Liberation Mono", Menlo, Courier, monospace;
        font-size: 1rem;
        line-height: 1.8;
        width: 55%; }

.marginnote code { 
        font-size: 0.9rem;
      }

pre code { padding: 0 2em; }

pre {
  width: 55%;
  overflow: scroll;
}

hr {
  width: 55%;
  float: left;
  clear: both;
}

.fullwidth { max-width: 95%; } 

ul {padding-left: 7%;}
ol {padding-left: 7%;}

.sidenote, .marginnote { float: right;
                          clear: right;
                          margin-right: -60%;
                          width: 50%;
                          margin-top: 0;
                          margin-bottom: 20px;
                          font-size: 1.0rem;
                          line-height: 1.96;
                          vertical-align: baseline;
                          position: relative; }

.marginnote a {font-size: 1.0rem;
                color: #777;  }
.sidenote a {font-size: 1.0rem;
                color: #777;  }

li .marginnote  { float: right;
                          clear: right;
                          margin-right: -64.52%;
                          width: 53.76%;
                          margin-top: 0;
                          margin-bottom: 20px;
                          font-size: 1.0rem;
                          line-height: 1.96;
                          vertical-align: baseline;
                          position: relative; }


.checklist { padding-left:20px; list-style: none; }

.checklist li { margin-bottom:10px; }
.checklist li:before {    
    font-family: FontAwesome;
    font-size: 11px;
    content: "\f096";
    margin:0 8px 0 -15px;
}

@media screen and (max-width: 600px) { .sidenote, .marginnote { width: 25%;
                                                                margin-right: -35%; }}
@media screen and (max-width: 400px) { .sidenote, .marginnote { display:none; }}

a.url { text-decoration: none;
        word-break: break-all;
        }

span.newthought { font-variant: small-caps; }

/* LaTeX-logo-specific styling */
.latex sub, .latex sup { text-transform: uppercase; }

.latex sub { vertical-align: 0.2rem;
             margin-left: -0.1667rem;
             margin-right: -0.125rem; }

.latex sup { vertical-align: -0.2rem;
             margin-left: -0.36rem;
             margin-right: -0.15rem; }

@media print { *, *:before, *:after { background: transparent !important;
                                      /* Black prints faster: http://www.sanbeiji.com/archives/953 */
                                      color: #000 !important; 
                                      box-shadow: none !important;
                                      text-shadow: none !important; }

               thead { display: table-header-group; }

               tr, img { page-break-inside: avoid; }

               img { max-width: 100% !important; }
               

               p, h2, h3 { orphans: 3;
                           widows: 3; }

               h2, h3 { page-break-after: avoid; }}